/*   Cataract - Static web photo gallery generator
 *   Copyright (C) 2008 Tomas Bzatek <tbzatek@users.sourceforge.net>
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#include "setup.h"
#include "items.h"


/*
 *   write_html_album: process album and index template files
 *
 *      template_src  = template file of the album/index
 *      dst           = save generated file as
 *      items         = array of items in the album/index
 *
 */
gboolean write_html_album (TGallerySetup *setup,
		                   const char *template_src,
		                   const char *dst,
		                   TAlbum *items);

/*
 *   write_html_image: process single image template file
 *
 *      template_src  = template file of the album/index
 *      original_img  = source image file (original full-size) to get EXIF data from
 *      dst           = save generated file as
 *      item          = data for the current item
 *      parent_items  = array of items in the album, to determine our position and make links to previous/next image
 *
 */
gboolean write_html_image (TGallerySetup *setup,
		                   const char *template_src,
		                   const char *original_img,
		                   const char *dst,
		                   TIndexItem *item,
		                   TAlbum *parent_items);

/*
 *   build_tree: generate complete gallery tree based on source xml files
 *
 *      src_tree      = source directory of the items
 *      dst_dir       = destination of the generated items
 *      parent_index  = parent album to determine our descent in the tree
 *
 */
gboolean build_tree (TGallerySetup *setup,
		             const char *src_tree,
		             const char *dst_dir,
		             TAlbum *parent_index);

